@@ -403,14 +403,17 @@ class Graph():
     def __str__(self) -> str:
         return f"GFA Graph object (version {self.version.value}) containing {len(self.segments)} segments, {len(self.lines)} edges and {len(self.paths)+len(self.walks)} paths."
 
-    def split_segments(self, segment_name: str, future_segment_name: str | list, position_to_split: int | list) -> None:
+    def split_segments(self, segment_name: str, future_segment_name: str | list, position_to_split: tuple | list) -> None:
         """Given a segment to split and a series/single new name(s) + position(s),
         breaks the node in multiple nodes and includes splits them in the Graph data
 
+        If you want to split the segment A into A,B, ... you must provide
+        self.split_segments(A,[A,B, ...],[(start_A,end_A),(start_B,end_B), ...])
+
         Args:
             segment_name (str): the name of the node to break
             future_segment_name (str | list): the name(s) of the future nodes
-            position_to_split (int | list): the position(s) where to split the sequence
+            position_to_split (int | list): the position(s) where to split the sequence (start,stop)
 
         Raises:
             ValueError: if the provided args aren't compatible
@@ -418,7 +421,7 @@ class Graph():
         node_to_split: Segment = self.get_segment(segment_name)
         if not isinstance(future_segment_name, Iterable):
             future_segment_name = [future_segment_name]
-        if not isinstance(position_to_split, Iterable):
+        if not isinstance(position_to_split, list):
             position_to_split = [position_to_split]
         if len(future_segment_name) != len(position_to_split):
             raise ValueError("Parameters does not have the same length.")
@@ -440,12 +443,12 @@ class Graph():
                 # Edge is incomming edge, should be kept
 
         # Edit first node
-        node_to_split.datas['seq'] = node_to_split.datas['seq'][:position_to_split[0]
-                                                                ] if 'seq' in node_to_split.datas else 'N'*position_to_split[0]
+        node_to_split.datas['seq'] = node_to_split.datas['seq'][:position_to_split[0][1]
+                                                                ] if 'seq' in node_to_split.datas else 'N'*position_to_split[0][1]
 
-        for i, pos1 in enumerate((positions := position_to_split)[:-1]):
+        for i, positions in enumerate(position_to_split):
             # Divide the node by creating an new one and updating attributes
-            pos2 = positions[i+1]
+            pos1, pos2 = positions
             new_seg: Segment = Segment()
             new_seg.datas = {}
             new_seg.datas['name'] = future_segment_name[i]
@@ -454,21 +457,31 @@ class Graph():
             self.segments.append(new_seg)
 
             # Create new edge between, re-assign sorting edges to new node
-            new_edge: Line = Line()
-            new_edge.datas = {}
-            new_edge.datas['start'] = future_segment_name[i]
-            new_edge.datas['end'] = future_segment_name[i+1]
-            # Get orientation of incomming edge and output edge, mix them for orientation of the new edge
-            new_edge.datas['orientation'] = f"{orient}/{orient}"
-            self.lines.append(new_edge)
+            try:
+                new_edge: Line = Line()
+                new_edge.datas = {}
+                new_edge.datas['start'] = future_segment_name[i]
+                new_edge.datas['end'] = future_segment_name[i+1]
+                # Get orientation of incomming edge and output edge, mix them for orientation of the new edge
+                new_edge.datas['orientation'] = f"{orient}/{orient}"
+                self.lines.append(new_edge)
+            except IndexError:
+                pass
 
             # Add to paths by inserting after node to be splitted
             for ipath in self.get_path_list():
-                for posx, (node, _) in enumerate(ipath.datas['path']):
-                    if node == segment_name:
+                edited: bool = False
+                for posx, sparkl in enumerate(ipath.datas['path']):
+                    node, _ = sparkl
+                    if node == segment_name and not edited:
+                        edited = True
+                        ipath.datas['path'].remove(sparkl)
                         ipath.datas['path'] = ipath.datas['path'][:posx] + [(nname, Orientation(
                             orient)) for nname in future_segment_name] + ipath.datas['path'][posx:]
 
+        # Remove the original segment
+        self.segments.remove(node_to_split)
+
     def merge_segments(self, *segs: str) -> str:
         """Given a series of nodes, merges it to the first of the series.
         """
@@ -478,6 +491,8 @@ class Graph():
             [seg for seg in segs], key=lambda x: int(sub('\D', '', str(x))))]
         left_most: Segment = self.segments[segments_positions[0]]
         right_most: Segment = self.segments[segments_positions[-1]]
+        names_to_be_deleted: list[str] = [
+            self.segments[segments_positions[i]].datas['name'] for i in range(1, len(segments_positions))]
 
         # Editing properties of node
         left_most.datas['length'] += sum([int(self.segments[i].datas['length'])
@@ -501,16 +516,9 @@ class Graph():
 
         # Edit the paths by iterating over all paths
         for ipath in self.get_path_list():
-            start_pos: int = 0
-            end_pos: int = 0
-            for i, (name, _) in enumerate(ipath.datas['path']):
-                if name == left_most_name:
-                    start_pos: int = i
-                elif name == right_most_name:
-                    end_pos: int = i
-            if start_pos and end_pos:
-                ipath.datas['path'] = ipath.datas['path'][:min(
-                    [start_pos, end_pos])] + ipath.datas['path'][max([start_pos, end_pos]):]
+            for elt in ipath.datas['path']:
+                if elt[0] in names_to_be_deleted:
+                    ipath.datas['path'].remove(elt)
 
         # Delete nodes and edges that are not relevant anymore
         self.segments = [seg for i, seg in enumerate(
